@@ -3,18 +3,19 @@ Tests for QtAwesome.
 """
 # Standard library imports
 import subprocess
+import sys
 import collections
 
 # Test Library imports
 import pytest
 
 # Local imports
-import qtawesome as qta
 from qtawesome.iconic_font import IconicFont
+import qtawesome as qta
 
 
 def test_segfault_import():
-    output_number = subprocess.call('python -c "import qtawesome '
+    output_number = subprocess.call(sys.executable + ' -c "import qtawesome '
                                     '; qtawesome.icon()"', shell=True)
     assert output_number == 0
 
